starcluster.tests.test_cluster_validation.TestClusterValidation

Package starcluster :: Package tests :: Module test_cluster_validation :: Class TestClusterValidation |
[hide private]
[frames] | no frames]

# Class TestClusterValidation

source code

Nested Classes | [hide private]
Inherited from `unittest.TestCase`: `failureException`

Instance Methods | [hide private]
test_aws_credentials_validation(self) | source code
test_plugin_loading(self) | source code
test_cluster_size_validation(self) | source code
test_shell_validation(self) | source code
test_keypair_validation(self) | source code
__test_cases_from_cfg(self, cases, test, cluster_name=`'``c1``'`) Tests all cases by loading a cluster template from the test config. | source code
__test_cases_from_cluster(self, cases, test) Tests all cases by manually loading a cluster template using the Cluster class. | source code
test_instance_type_validation(self) | source code
test_ebs_validation(self) | source code
test_permission_validation(self) | source code
Inherited from `StarClusterTest`: `get_config`, `get_custom_config` Inherited from `unittest.TestCase`: `__call__`, `__eq__`, `__hash__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `assertAlmostEqual`, `assertAlmostEquals`, `assertEqual`, `assertEquals`, `assertFalse`, `assertNotAlmostEqual`, `assertNotAlmostEquals`, `assertNotEqual`, `assertNotEquals`, `assertRaises`, `assertTrue`, `assert_`, `countTestCases`, `debug`, `defaultTestResult`, `fail`, `failIf`, `failIfAlmostEqual`, `failIfEqual`, `failUnless`, `failUnlessAlmostEqual`, `failUnlessEqual`, `failUnlessRaises`, `id`, `run`, `setUp`, `shortDescription`, `tearDown` Inherited from `unittest.TestCase` (private): `_exc_info` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `StarClusterTest`: `config` Inherited from `object`: `__class__`

Method Details | [hide private]

### __test_cases_from_cfg(self, cases, test, cluster_name=`'``c1``'`) | source code
Tests all cases by loading a cluster template from the test config. This method will write a custom test config for each case using its settings.

### __test_cases_from_cluster(self, cases, test) | source code
Tests all cases by manually loading a cluster template using the Cluster class. All settings for a case are passed in as constructor keywords. Avoids the config module by using the Cluster object directly to create a test case.